responsive_window library
A lightweight app-level responsive window utility for Flutter.
Provides a root responsive scope with Material Design 3-inspired width breakpoints for building adaptive Flutter apps.
Classes
- ResponsiveWindow
- Provides responsive app window data to the widget subtree.
- ResponsiveWindowBuilder
- Builds a responsive widget based on the current ResponsiveWindowCategory.
- ResponsiveWindowData
- Immutable layout data for the current responsive app window scope.
-
ResponsiveWindowValue<
T> - Resolves a value based on the current ResponsiveWindowCategory.
Enums
- ResponsiveWindowCategory
- Represents the responsive category for the available app window width.
Extensions
- BuildContextResponsiveWindow on BuildContext
- Convenience extension for accessing ResponsiveWindowData from a BuildContext.
Typedefs
- ResponsiveWindowWidgetBuilder = Widget Function(BuildContext context, ResponsiveWindowData windowData)
- Builds a widget using the current ResponsiveWindowData.